==> node-core-js_3.6.1.orig.tar.gz: core-js-3.6.1/packages/core-js-compat/src/modules-by-versions.js <==
'use strict';
module.exports = {
  3.1: [
    'es.string.match-all',
    'es.symbol.match-all',
    'esnext.symbol.replace-all',
  ],
  3.2: [
    'es.promise.all-settled',
    'esnext.array.is-template-object',
    'esnext.map.update-or-insert',
    'esnext.symbol.async-dispose',
  ],
  3.3: [
    'es.global-this',
    'esnext.async-iterator.constructor',
    'esnext.async-iterator.as-indexed-pairs',
    'esnext.async-iterator.drop',
    'esnext.async-iterator.every',
    'esnext.async-iterator.filter',
    'esnext.async-iterator.find',
    'esnext.async-iterator.flat-map',
    'esnext.async-iterator.for-each',
    'esnext.async-iterator.from',
    'esnext.async-iterator.map',
    'esnext.async-iterator.reduce',
    'esnext.async-iterator.some',
    'esnext.async-iterator.take',
    'esnext.async-iterator.to-array',
    'esnext.iterator.constructor',
    'esnext.iterator.as-indexed-pairs',
    'esnext.iterator.drop',
    'esnext.iterator.every',
    'esnext.iterator.filter',
    'esnext.iterator.find',
    'esnext.iterator.flat-map',
    'esnext.iterator.for-each',
    'esnext.iterator.from',
    'esnext.iterator.map',
    'esnext.iterator.reduce',
    'esnext.iterator.some',
    'esnext.iterator.take',
    'esnext.iterator.to-array',
    'esnext.map.upsert',
    'esnext.weak-map.upsert',
  ],
  3.4: [
    'es.json.stringify',
  ],
  3.5: [
    'esnext.object.iterate-entries',
    'esnext.object.iterate-keys',
    'esnext.object.iterate-values',
  ],
  3.6: [
    'es.regexp.sticky',
    'es.regexp.test',
  ],
};

==> node-core-js_3.8.2.orig.tar.gz: core-js-3.8.2/packages/core-js-compat/src/modules-by-versions.js <==
'use strict';
module.exports = {
  3.1: [
    'es.string.match-all',
    'es.symbol.match-all',
    'esnext.symbol.replace-all',
  ],
  3.2: [
    'es.promise.all-settled',
    'esnext.array.is-template-object',
    'esnext.map.update-or-insert',
    'esnext.symbol.async-dispose',
  ],
  3.3: [
    'es.global-this',
    'esnext.async-iterator.constructor',
    'esnext.async-iterator.as-indexed-pairs',
    'esnext.async-iterator.drop',
    'esnext.async-iterator.every',
    'esnext.async-iterator.filter',
    'esnext.async-iterator.find',
    'esnext.async-iterator.flat-map',
    'esnext.async-iterator.for-each',
    'esnext.async-iterator.from',
    'esnext.async-iterator.map',
    'esnext.async-iterator.reduce',
    'esnext.async-iterator.some',
    'esnext.async-iterator.take',
    'esnext.async-iterator.to-array',
    'esnext.iterator.constructor',
    'esnext.iterator.as-indexed-pairs',
    'esnext.iterator.drop',
    'esnext.iterator.every',
    'esnext.iterator.filter',
    'esnext.iterator.find',
    'esnext.iterator.flat-map',
    'esnext.iterator.for-each',
    'esnext.iterator.from',
    'esnext.iterator.map',
    'esnext.iterator.reduce',
    'esnext.iterator.some',
    'esnext.iterator.take',
    'esnext.iterator.to-array',
    'esnext.map.upsert',
    'esnext.weak-map.upsert',
  ],
  3.4: [
    'es.json.stringify',
  ],
  3.5: [
    'esnext.object.iterate-entries',
    'esnext.object.iterate-keys',
    'esnext.object.iterate-values',
  ],
  3.6: [
    'es.regexp.sticky',
    'es.regexp.test',
  ],
  3.7: [
    'es.aggregate-error',
    'es.promise.any',
    'es.reflect.to-string-tag',
    'es.string.replace-all',
    'esnext.map.emplace',
    'esnext.weak-map.emplace',
  ],
  3.8: [
    'esnext.array.at',
    'esnext.array.filter-out',
    'esnext.array.unique-by',
    'esnext.bigint.range',
    'esnext.number.range',
    'esnext.typed-array.at',
    'esnext.typed-array.filter-out',
  ],
};
